@@ -15,4 +15,5 @@
 from .db import *
 from .db.mysql import MySQL
 from .db.hive import Hive
-from .WeChat import WeChat
\ No newline at end of file
+from .WeChat import WeChat,Chat
+from .Time import Time
